! { dg-do compile }
SUBROUTINE A7_1(A,N)
INTEGER OMP_GET_THREAD_NUM
REAL A(*)
INTEGER I, MYOFFSET, N
!$OMP PARALLEL PRIVATE(MYOFFSET)
       MYOFFSET = OMP_GET_THREAD_NUM()*N
       DO I = 1, N
          A(MYOFFSET+I) = FLOAT(I)
       ENDDO
!$OMP END PARALLEL
END SUBROUTINE A7_1
